@@ -1,6 +1,9 @@
-#' @importFrom effectsize change_scale
 #' @export
-data_plot.see_easycormatrix <- function(x, data = NULL, digits = 3, size = 1, ...) {
+data_plot.see_easycormatrix <- function(x,
+                                        data = NULL,
+                                        digits = 3,
+                                        size = 1,
+                                        ...) {
   legend_fill <- attr(x, "coefficient_name")
   redundant <- attr(x, "redundant")
 
@@ -60,11 +63,12 @@ data_plot.see_easycormatrix <- function(x, data = NULL, digits = 3, size = 1, ..
 
 #' Plot method for correlation matrices
 #'
-#' The \code{plot()} method for the \code{correlation::correlation()} function.
+#' The `plot()` method for the `correlation::correlation()` function.
 #'
-#' @param show_values Logical, if \code{TRUE}, values are displayed.
-#' @param show_p Logical, if \code{TRUE}, p-values or significant level is displayed.
-#' @param show_legend Logical, show or hide legend.
+#' @param show_labels Logical. If `TRUE`, correlation values are displayed.
+#' @param show_p Logical. If `TRUE`, *p*-values or significant level is
+#'   displayed.
+#' @param show_legend Logical, show (`TRUE`) or hide (`FALSE`) legend.
 #' @param digits Number of decimals used for values.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_check_normality
@@ -79,21 +83,35 @@ data_plot.see_easycormatrix <- function(x, data = NULL, digits = 3, size = 1, ..
 #' result <- correlation(mtcars[, -c(8:9)])
 #' s <- summary(result)
 #' plot(s)
-#' @importFrom insight format_p
 #' @export
-plot.see_easycormatrix <- function(x, show_values = FALSE, show_p = FALSE, show_legend = TRUE, size_point = 1, size_text = 3.5, digits = 3, type = c("circle", "tile"), ...) {
+plot.see_easycormatrix <- function(x,
+                                   show_labels = FALSE,
+                                   show_p = FALSE,
+                                   show_legend = TRUE,
+                                   size_point = 1,
+                                   size_text = 3.5,
+                                   digits = 3,
+                                   type = c("circle", "tile"),
+                                   ...) {
   if (!"data_plot" %in% class(x)) {
     x <- data_plot(x, digits = digits, size = size_point)
   }
 
+  # accept deprecated `show_values` argument
+  if (!is.null(list(...)$show_values)) show_labels <- list(...)$show_values
+
   type <- match.arg(type)
 
   if (show_p) {
     non_empty <- x$labels != ""
-    x$labels[non_empty] <- paste0(
-      x$labels[non_empty],
-      insight::format_p(x$p, stars_only = TRUE)[non_empty]
-    )
+    if (show_labels) {
+      x$labels[non_empty] <- paste0(
+        x$labels[non_empty],
+        insight::format_p(x$p, stars_only = TRUE)[non_empty]
+      )
+    } else {
+      x$labels[non_empty] <- insight::format_p(x$p)[non_empty]
+    }
   }
 
   if (type == "tile") {
@@ -120,7 +138,7 @@ plot.see_easycormatrix <- function(x, show_values = FALSE, show_p = FALSE, show_
     theme(axis.line = element_blank()) +
     add_plot_attributes(x)
 
-  if (show_values) {
+  if (show_labels || show_p) {
     p <- p + geom_text(aes(label = .data$labels), size = size_text, color = "black")
   }
 
