@@ -1,7 +1,8 @@
-#' @importFrom parameters simulate_model
-#' @importFrom bayestestR estimate_density
 #' @export
-data_plot.parameters_simulate <- function(x, data = NULL, normalize_height = FALSE, ...) {
+data_plot.parameters_simulate <- function(x,
+                                          data = NULL,
+                                          normalize_height = FALSE,
+                                          ...) {
   if (is.null(data)) {
     data <- .retrieve_data(x)
   }
@@ -59,12 +60,14 @@ data_plot.parameters_simulate <- function(x, data = NULL, normalize_height = FAL
 
 #' Plot method for simulated model parameters
 #'
-#' The \code{plot()} method for the \code{parameters::simulate_parameters()} function.
+#' The `plot()` method for the `parameters::simulate_parameters()`
+#' function.
 #'
-#' @param normalize_height Logical, if \code{TRUE}, height of density-areas is
+#' @param normalize_height Logical. If `TRUE`, height of density-areas is
 #'   "normalized", to avoid overlap. In certain cases when the range of a
-#'   distribution of simulated draws is narrow for some parameters, this may result in
-#'   very flat density-areas. In such cases, set \code{normalize_height = FALSE}.
+#'   distribution of simulated draws is narrow for some parameters, this may
+#'   result in very flat density-areas. In such cases, set
+#'   `normalize_height = FALSE`.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_estimate_density
 #' @inheritParams plot.see_bayesfactor_parameters
