@@ -1,4 +1,3 @@
-#' @importFrom bayestestR point_estimate
 #' @export
 data_plot.point_estimate <- function(x, data = NULL, ...) {
   if (is.null(data)) {
@@ -6,9 +5,8 @@ data_plot.point_estimate <- function(x, data = NULL, ...) {
   }
 
   if (inherits(data, "emmGrid")) {
-    if (!requireNamespace("emmeans", quietly = TRUE)) {
-      stop("Package 'emmeans' required for this function to work. Please install it.", call. = FALSE)
-    }
+    insight::check_if_installed("emmeans")
+
     data <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(data, names = FALSE)))
   } else if (inherits(data, c("stanreg", "brmsfit"))) {
     data <- insight::get_parameters(data, effects = "all", component = "all")
@@ -78,12 +76,12 @@ data_plot.map_estimate <- data_plot.point_estimate
 
 #' Plot method for point estimates of posterior samples
 #'
-#' The \code{plot()} method for the \code{bayestestR::point_estimate()}.
+#' The `plot()` method for the `bayestestR::point_estimate()`.
 #'
-#' @param show_labels Logical, if \code{TRUE}, the text labels for the point
-#'   estimates (i.e. \emph{"Mean"}, \emph{"Median"} and/or \emph{"MAP"}) are shown.
-#'   You may set \code{show_labels = FALSE} in case of overlapping labels, and
-#'   add your own legend or footnote to the plot.
+#' @param show_labels Logical. If `TRUE`, the text labels for the point
+#'   estimates (i.e. *"Mean"*, *"Median"* and/or *"MAP"*) are
+#'   shown. You may set `show_labels = FALSE` in case of overlapping
+#'   labels, and add your own legend or footnote to the plot.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
 #' @inheritParams plot.see_check_outliers
@@ -165,7 +163,10 @@ plot.see_point_estimate <- function(x,
     }
 
     p_object <- p_object +
-      geom_ribbon(aes(ymin = 0, ymax = .data$y), fill = "#FFC107", alpha = posterior_alpha)
+      geom_ribbon(aes(ymin = 0, ymax = .data$y),
+        fill = "#FFC107",
+        alpha = posterior_alpha
+      )
 
     if (!is.null(mean_x) && !is.null(mean_y)) {
       p_object <- p_object +
